ApisResponseV2CheckStatusResponseV2StatusEnumTypeTransformer class
Transformation class that can encode an instance of ApisResponseV2CheckStatusResponseV2StatusEnum to String, and decode dynamic data back to ApisResponseV2CheckStatusResponseV2StatusEnum.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
dynamic data, {bool allowNull = true}) → ApisResponseV2CheckStatusResponseV2StatusEnum? -
Decodes a
datato a ApisResponseV2CheckStatusResponseV2StatusEnum. -
encode(
ApisResponseV2CheckStatusResponseV2StatusEnum data) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited