ApisResponseV2StringStatusEnumTypeTransformer class

Transformation class that can encode an instance of ApisResponseV2StringStatusEnum to String, and decode dynamic data back to ApisResponseV2StringStatusEnum.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(dynamic data, {bool allowNull = true}) → ApisResponseV2StringStatusEnum?
Decodes a data to a ApisResponseV2StringStatusEnum.
encode(ApisResponseV2StringStatusEnum data) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited