CalculeFraisOperationRequest class
Constructors
- CalculeFraisOperationRequest({required String indicatifExpediteur, required String numeroExpediteur, required double montant, required bool fraisInclus, required String villeExpedition, required String villeDestination, CalculeFraisOperationRequestProfilEnum profil = const CalculeFraisOperationRequestProfilEnum._('CCP')})
- Returns a new CalculeFraisOperationRequest instance.
Properties
- fraisInclus ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- indicatifExpediteur ↔ String
-
getter/setter pair
- montant ↔ double
-
getter/setter pair
- numeroExpediteur ↔ String
-
getter/setter pair
- profil ↔ CalculeFraisOperationRequestProfilEnum
-
Grille tarifaire du reseau de retrait cash : CCP (Niger Poste, defaut) ou BIN.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- villeDestination ↔ String
-
getter/setter pair
- villeExpedition ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → CalculeFraisOperationRequest? -
Returns a new CalculeFraisOperationRequest instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< CalculeFraisOperationRequest> -
mapFromJson(
dynamic json) → Map< String, CalculeFraisOperationRequest> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< CalculeFraisOperationRequest> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.