CompteV2Api class

Constructors

CompteV2Api([ApiClient? apiClient])

Properties

apiClient → ApiClient
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

consulterSoldeCompte() → Future<ApisResponseV2Double?>
Consulter le solde du compte
consulterSoldeCompteWithHttpInfo() → Future<Response>
Consulter le solde du compte
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited