EnvoiInterPartenaireRequest class

Constructors

EnvoiInterPartenaireRequest({String? requestId, String? partenaireDestinataireAlias, String? compteDestinataire, double? montantTransaction, String? typeFraisEnvoi, String? motifTransaction, String? compteExpediteur})
Returns a new EnvoiInterPartenaireRequest instance.

Properties

compteDestinataire ↔ String?
Libellé du compte destinataire (optionnel si unique).
getter/setter pair
compteExpediteur ↔ String?
Libellé du compte expéditeur (optionnel si unique).
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
montantTransaction ↔ double?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
motifTransaction ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
partenaireDestinataireAlias ↔ String?
Alias du partenaire destinataire (même organisation).
getter/setter pair
requestId ↔ String?
Votre référence d'opération (idempotence).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeFraisEnvoi ↔ String?
fraisApars (défaut) ou fraisInclus.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → EnvoiInterPartenaireRequest?
Returns a new EnvoiInterPartenaireRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<EnvoiInterPartenaireRequest>
mapFromJson(dynamic json) → Map<String, EnvoiInterPartenaireRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<EnvoiInterPartenaireRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.