FraisPreviewResponseV2 class

Constructors

FraisPreviewResponseV2({double? montant, double? frais, double? timbre, double? montantReduction, double? montantDebite, double? montantRecu, bool? fraisInclus, String? devise})
Returns a new FraisPreviewResponseV2 instance.

Properties

devise ↔ String?
Devise des montants (XOF).
getter/setter pair
frais ↔ double?
Frais NITA applicables.
getter/setter pair
fraisInclus ↔ bool?
true = frais deduits du montant, false = frais en sus.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
montant ↔ double?
Montant de la transaction demande.
getter/setter pair
montantDebite ↔ double?
Total debite du compte partenaire.
getter/setter pair
montantRecu ↔ double?
Montant net recu par le beneficiaire.
getter/setter pair
montantReduction ↔ double?
Reduction appliquee (0 si aucune).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timbre ↔ double?
Timbre fiscal (0 si non applicable).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → FraisPreviewResponseV2?
Returns a new FraisPreviewResponseV2 instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<FraisPreviewResponseV2>
mapFromJson(dynamic json) → Map<String, FraisPreviewResponseV2>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<FraisPreviewResponseV2>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.