GetPartenaireToWalletModel class

Constructors

GetPartenaireToWalletModel({required String requestId, required String codeRecharge})
Returns a new GetPartenaireToWalletModel instance.

Properties

codeRecharge ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
requestId ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → GetPartenaireToWalletModel?
Returns a new GetPartenaireToWalletModel instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<GetPartenaireToWalletModel>
mapFromJson(dynamic json) → Map<String, GetPartenaireToWalletModel>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<GetPartenaireToWalletModel>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.