LocalitsV2Api class

Constructors

LocalitsV2Api([ApiClient? apiClient])

Properties

apiClient → ApiClient
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllActiveVillesListe() → Future<ApisResponseV2ListVilleResponse?>
Obtenir la liste des villes actives
getAllActiveVillesListeWithHttpInfo() → Future<Response>
Obtenir la liste des villes actives
getAllIndicatifs() → Future<ApisResponseV2IndicatifsResponseV2?>
Obtenir la liste des indicatifs téléphoniques de tous les pays actifs
getAllIndicatifsWithHttpInfo() → Future<Response>
Obtenir la liste des indicatifs téléphoniques de tous les pays actifs
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited