toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() => 'PartenaireToWalletResponseV2[publicId=$publicId, requestId=$requestId, adresseIP=$adresseIP, reference=$reference, motif=$motif, montantRecharge=$montantRecharge, fraisRecharge=$fraisRecharge, montantTotalTransaction=$montantTotalTransaction, statusTransaction=$statusTransaction, typeTransaction=$typeTransaction, compteClient=$compteClient, nomDeposant=$nomDeposant, prenomDeposant=$prenomDeposant, phoneDeposant=$phoneDeposant, typePieceDeposant=$typePieceDeposant, numeroPieceDeposant=$numeroPieceDeposant, comptePartenaire=$comptePartenaire, nomPartenaire=$nomPartenaire, prenomPartenaire=$prenomPartenaire, dateTransaction=$dateTransaction]';