EnvoiInterPartenaireRequest class
Properties
-
compteDestinataire
↔ String?
-
Libellé du compte destinataire (optionnel si unique).
getter/setter pair
-
compteExpediteur
↔ String?
-
Libellé du compte expéditeur (optionnel si unique).
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
montantTransaction
↔ double?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
motifTransaction
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
partenaireDestinataireAlias
↔ String?
-
Alias du partenaire destinataire (même organisation).
getter/setter pair
-
requestId
↔ String?
-
Votre référence d'opération (idempotence).
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
typeFraisEnvoi
↔ String?
-
fraisApars (défaut) ou fraisInclus.
getter/setter pair