PartenaireToWalletModel class
Constructors
-
PartenaireToWalletModel({String? phoneClient, double? montantTransaction, String? longTransaction, String? latTransaction, String? motifTransaction, String? requestId, String? adresseIp, String? phoneDeposant, String? nomDeposant, String? prenomDeposant, String? typePieceDeposant, String? numeroPieceDeposant})
-
Returns a new PartenaireToWalletModel instance.
Properties
-
adresseIp
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
latTransaction
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
longTransaction
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
montantTransaction
↔ double?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
motifTransaction
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
nomDeposant
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
numeroPieceDeposant
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
phoneClient
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
phoneDeposant
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
prenomDeposant
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
requestId
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
typePieceDeposant
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair